#ifndef EDV_ARCHIVE_CHK_H
#define EDV_ARCHIVE_CHK_H

#include <gtk/gtk.h>
#include "edv_types.h"


extern const gchar *EDVArchChkGetError(edv_core_struct *core);

extern gint EDVArchChk(
        edv_core_struct *core,
        const gchar *arch_path,
        const gchar *password,
        GtkWidget *toplevel,
        const gboolean show_progress, const gboolean interactive,
	gboolean *yes_to_all
);


#endif	/* EDV_ARCHIVE_CHK_H */
